@@ -58,6 +58,8 @@ struct song *song_alloc(void);
 void song_free(struct song *);
 void song_insertblock(struct song *, int);
 void song_deleteblock(struct song *, int);
+void song_insertplayseq(struct song *, int);
+void song_deleteplayseq(struct song *, int);
 void song_insertsection(struct song *, int);
 void song_deletesection(struct song *, int);
 void song_setsection(struct song *, int, int);
