@@ -44,7 +44,8 @@ GtkWidget *gui_main_edit, *gui_main_space, *gui_main_octave, *gui_main_tracker;
 GtkWidget *gui_file_open, *gui_file_saveas;
 
 /* Tempo window GTK widgets */
-GtkWidget *gui_tempo_window, *gui_tempo_adjustment_tempo, *gui_tempo_adjustment_tpl;
+GtkWidget *gui_tempo_window, *gui_tempo_adjustment_tempo;
+GtkWidget *gui_tempo_adjustment_tpl;
 
 /* Information window GTK widgets */
 GtkWidget *gui_info_song, *gui_info_section, *gui_info_playseq;
@@ -52,16 +53,16 @@ GtkWidget *gui_info_block1, *gui_info_block2;
 GtkWidget *gui_info_status, *gui_info_timer;
 
 /* Section List window GTK widgets */
-GtkWidget *gui_sectionlist_window, *gui_sectionlist_current, *gui_sectionlist_playseq;
-GtkWidget *gui_sectionlist_clist;
+GtkWidget *gui_sectionlist_window, *gui_sectionlist_current;
+GtkWidget *gui_sectionlist_playseq, *gui_sectionlist_clist;
 
 /* Playing Sequence window GTK widgets */
 GtkWidget *gui_playseq_window, *gui_playseq_current, *gui_playseq_block;
-GtkWidget *gui_playseq_clist;
+GtkWidget *gui_playseq_clist, *gui_playseq_name;
 
 /* Block List window GTK widgets */
 GtkWidget *gui_blocklist_window, *gui_blocklist_current, *gui_blocklist_clist;
-GtkWidget *gui_blocklist_entry_name, *gui_blocklist_tracks;
+GtkWidget *gui_blocklist_name, *gui_blocklist_tracks;
 GtkWidget *gui_blocklist_length, *gui_blocklist_effectpages;
 
 /* Instrument properties window GTK widgets */
@@ -136,10 +137,10 @@ void gui_file_saveas_clicked(GtkFileSelection *selector, gpointer user_data) {
 
 void gui_create() {
   GtkWidget *w1, *w2, *w3, *w4, *mainvbox, *tophbox, *instrvbox;
-  char *sectionlist_titles[3]={ "Position", "Playing Sequence Number",
-			    "Playing Sequence Name" };
-  char *playseq_titles[3]={ "Position", "Block Number", "Block Name" };
-  char *blocklist_titles[2]={ "Number", "Name" };
+  char *sectionlist_titles[3]={ "Section", "Playing Sequence",
+				"Playing Sequence Name" };
+  char *playseq_titles[3]={ "Position", "Block", "Block Name" };
+  char *blocklist_titles[2]={ "Block", "Name" };
 
   /* Main window */
   gui_main_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -424,11 +425,11 @@ void gui_create() {
 
   w3=gtk_frame_new(NULL);
   gtk_frame_set_shadow_type(GTK_FRAME(w3), GTK_SHADOW_ETCHED_IN);
-  gtk_box_pack_start(GTK_BOX(w1), w3, TRUE, TRUE, 4);
-  w2=gtk_vbox_new(FALSE,2);
+  gtk_box_pack_start(GTK_BOX(w1), w3, TRUE, TRUE, 0);
+  w2=gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(w3), w2);
-  w3=gtk_hbox_new(FALSE,4);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
+  w3=gtk_hbox_new(FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
   w4=gtk_label_new("Tempo");
   gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
   gui_tempo_adjustment_tempo=(GtkWidget *)gtk_adjustment_new(DEFAULT_TEMPO, 1,
@@ -439,8 +440,8 @@ void gui_create() {
   gtk_scale_set_digits(GTK_SCALE(w4), 0);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
   w3=gtk_hbox_new(FALSE,4);
-  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 4);
-  w4=gtk_label_new("TPL");
+  gtk_box_pack_start(GTK_BOX(w2), w3, TRUE, TRUE, 0);
+  w4=gtk_label_new("Ticks Per Line");
   gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
   gui_tempo_adjustment_tpl=(GtkWidget *)gtk_adjustment_new(6, 1, 32, 1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_tempo_adjustment_tpl), "value_changed",
@@ -508,11 +509,11 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
   w4=gtk_button_new_with_label("Insert");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
-		     GTK_SIGNAL_FUNC(gui_sectionlist_insnew), NULL);
+		     GTK_SIGNAL_FUNC(gui_sectionlist_insert), NULL);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
   w4=gtk_button_new_with_label("Append");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
-		     GTK_SIGNAL_FUNC(gui_sectionlist_appnew), NULL);
+		     GTK_SIGNAL_FUNC(gui_sectionlist_append), NULL);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
   w4=gtk_button_new_with_label("Delete");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
@@ -527,7 +528,7 @@ void gui_create() {
   /* Playing sequence window */
   gui_playseq_window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_container_set_border_width(GTK_CONTAINER(gui_playseq_window), 4);
-  gtk_window_set_title(GTK_WINDOW(gui_playseq_window), "Playing Sequence");
+  gtk_window_set_title(GTK_WINDOW(gui_playseq_window), "Playing Sequence 0/0");
   gtk_widget_add_events(GTK_WIDGET(gui_playseq_window), GDK_KEY_RELEASE_MASK);
   gtk_signal_connect(GTK_OBJECT(gui_playseq_window), "key_press_event",
 		     GTK_SIGNAL_FUNC(keyboard_event), (gpointer)1);
@@ -556,7 +557,7 @@ void gui_create() {
   gui_playseq_current=gtk_frame_new("Position 1/1");
   gtk_frame_set_shadow_type(GTK_FRAME(gui_playseq_current),
 			    GTK_SHADOW_ETCHED_IN);
-  gtk_box_pack_start(GTK_BOX(w1), gui_playseq_current, FALSE, FALSE, 4);
+  gtk_box_pack_start(GTK_BOX(w1), gui_playseq_current, FALSE, FALSE, 0);
   w2=gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(gui_playseq_current), w2);
 
@@ -577,11 +578,43 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
   w4=gtk_button_new_with_label("Insert");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
-		     GTK_SIGNAL_FUNC(gui_playseq_insnew), NULL);
+		     GTK_SIGNAL_FUNC(gui_playseq_insert), NULL);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
   w4=gtk_button_new_with_label("Append");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
-		     GTK_SIGNAL_FUNC(gui_playseq_appnew), NULL);
+		     GTK_SIGNAL_FUNC(gui_playseq_append), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
+  w4=gtk_button_new_with_label("Delete");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_playseq_delete), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+
+#ifdef hrr
+  gui_playseq_playseq=gtk_frame_new("Playing Sequence 0/0");
+  gtk_frame_set_shadow_type(GTK_FRAME(gui_playseq_playseq),
+			    GTK_SHADOW_ETCHED_IN);
+  gtk_box_pack_start(GTK_BOX(w1), gui_playseq_playseq, FALSE, FALSE, 4);
+  w2=gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(gui_playseq_playseq), w2);
+#endif
+  w3=gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(w1), w3, FALSE, FALSE, 4);
+  w4=gtk_label_new("Name");
+  gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
+  gtk_label_set_justify(GTK_LABEL(w4), GTK_JUSTIFY_RIGHT);
+  gui_playseq_name=gtk_entry_new();
+  gtk_signal_connect(GTK_OBJECT(gui_playseq_name), "activate",
+		     GTK_SIGNAL_FUNC(gui_playseq_activate_name), gui_playseq_name);
+  gtk_box_pack_start(GTK_BOX(w3), gui_playseq_name, TRUE, TRUE, 4);
+  w3=gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(w1), w3, FALSE, FALSE, 4);
+  w4=gtk_button_new_with_label("Insert New");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_playseq_insertnew), NULL);
+  gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
+  w4=gtk_button_new_with_label("Append New");
+  gtk_signal_connect(GTK_OBJECT(w4), "clicked",
+		     GTK_SIGNAL_FUNC(gui_playseq_appendnew), NULL);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
   w4=gtk_button_new_with_label("Delete");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
@@ -631,10 +664,10 @@ void gui_create() {
   w4=gtk_label_new("Name");
   gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
   gtk_label_set_justify(GTK_LABEL(w4), GTK_JUSTIFY_RIGHT);
-  gui_blocklist_entry_name=gtk_entry_new();
-  gtk_signal_connect(GTK_OBJECT(gui_blocklist_entry_name), "activate",
-		     GTK_SIGNAL_FUNC(gui_blocklist_activate_name), gui_blocklist_entry_name);
-  gtk_box_pack_start(GTK_BOX(w3), gui_blocklist_entry_name, TRUE, TRUE, 4);
+  gui_blocklist_name=gtk_entry_new();
+  gtk_signal_connect(GTK_OBJECT(gui_blocklist_name), "activate",
+		     GTK_SIGNAL_FUNC(gui_blocklist_activate_name), gui_blocklist_name);
+  gtk_box_pack_start(GTK_BOX(w3), gui_blocklist_name, TRUE, TRUE, 4);
 
   w3=gtk_hbox_new(FALSE, 4);
   gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 0);
@@ -665,11 +698,11 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w2), w3, FALSE, FALSE, 4);
   w4=gtk_button_new_with_label("Insert New");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
-		     GTK_SIGNAL_FUNC(gui_blocklist_insnew), NULL);
+		     GTK_SIGNAL_FUNC(gui_blocklist_insert), NULL);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
   w4=gtk_button_new_with_label("Append New");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
-		     GTK_SIGNAL_FUNC(gui_blocklist_appnew), NULL);
+		     GTK_SIGNAL_FUNC(gui_blocklist_append), NULL);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 0);
   w4=gtk_button_new_with_label("Delete");
   gtk_signal_connect(GTK_OBJECT(w4), "clicked",
@@ -913,7 +946,7 @@ void gui_sectionlist_select_row(GtkWidget *list, gint row, gint column,
   char playseq[17+8];
 
   editor.section=row;
-  editor.playseq=editor.song->sections[editor.section];
+  refresh_playseq_and_block();
 
   snprintf(section, 8+8, "Section %d/%d", editor.section+1,
 	   editor.song->numsections);
@@ -923,56 +956,56 @@ void gui_sectionlist_select_row(GtkWidget *list, gint row, gint column,
   gtk_frame_set_label(GTK_FRAME(gui_sectionlist_current), section);
   gtk_label_set_text(GTK_LABEL(gui_sectionlist_playseq), playseq);
 
+  gui_playseq_refresh();
   gui_info_refresh();
 }
 
-#ifdef hmm
-void sectionlist_activate_name(GtkWidget *widget, GtkWidget *entry) {
+void gui_playseq_activate_name(GtkWidget *widget, GtkWidget *entry) {
   char *name=gtk_entry_get_text(GTK_ENTRY(entry));
 
-  if(editor.song->sections[editor.section]->name)
-    free(editor.song->sections[editor.section]->name);
-
-  editor.song->sections[editor.section]->name=(char *)strdup(name);
+  if(editor.song->playseqs[editor.playseq]->name)
+    free(editor.song->playseqs[editor.playseq]->name);
+  
+  editor.song->playseqs[editor.playseq]->name=(char *)strdup(name);
+  
+  gui_playseq_refresh();
+}
 
+void gui_sectionlist_insert() {
+  song_insertsection(editor.song, editor.section);
   gui_sectionlist_refresh();
 }
-#endif
 
-void gui_sectionlist_insnew() {
-  if(editor.song!=NULL) {
-    song_insertsection(editor.song, editor.section);
-    gui_sectionlist_refresh();
-  }
-}
-
-void gui_sectionlist_appnew() {
-  if(editor.song!=NULL) {
-    song_insertsection(editor.song, editor.song->numsections);
-    gui_sectionlist_refresh();
-  }
+void gui_sectionlist_append() {
+  song_insertsection(editor.song, editor.song->numsections);
+  gui_sectionlist_refresh();
 }
 
 void gui_sectionlist_delete() {
-  if(editor.song!=NULL) {
-    song_deletesection(editor.song, editor.section);
-    if(editor.section>=editor.song->numsections)
-      editor.section=editor.song->numsections-1;
-    gui_sectionlist_refresh();
-  }
+  song_deletesection(editor.song, editor.section);
+  if(editor.section>=editor.song->numsections)
+    editor.section=editor.song->numsections-1;
+
+  refresh_playseq_and_block();
+  gui_playseq_refresh();
+  gui_sectionlist_refresh();
 }
 
 void gui_sectionlist_previous() {
-  if(editor.song->sections[editor.playseq]>0)
-    editor.song->sections[editor.playseq]--;
+  if(editor.song->sections[editor.section]>0)
+    editor.song->sections[editor.section]--;
 
+  refresh_playseq_and_block();
+  gui_playseq_refresh();
   gui_sectionlist_refresh();
 }
 
 void gui_sectionlist_next() {
-  if(editor.song->sections[editor.playseq]<editor.song->numplayseqs-1)
-    editor.song->sections[editor.playseq]++;
+  if(editor.song->sections[editor.section]<editor.song->numplayseqs-1)
+    editor.song->sections[editor.section]++;
 
+  refresh_playseq_and_block();
+  gui_playseq_refresh();
   gui_sectionlist_refresh();
 }
 
@@ -991,17 +1024,17 @@ void gui_playseq_refresh() {
   char position[9+8];
   char block[6+8];
   char *columns[3];
-  char title[21];
+  char title[24];
 
   gtk_clist_freeze(GTK_CLIST(gui_playseq_clist));
   gtk_clist_clear(GTK_CLIST(gui_playseq_clist));
   columns[0]=position;
   columns[1]=block;
-  for(i=0; i<editor.song->playseqs[editor.section]->length; i++) {
+  for(i=0; i<editor.song->playseqs[editor.playseq]->length; i++) {
     snprintf(position, 4, "%0.3d", i+1);
     snprintf(block, 4, "%0.3d",
-	     editor.song->playseqs[editor.section]->blocknumbers[i]);
-    columns[2]=editor.song->blocks[editor.song->playseqs[editor.section]->blocknumbers[i]]->name;
+	     editor.song->playseqs[editor.playseq]->blocknumbers[i]);
+    columns[2]=editor.song->blocks[editor.song->playseqs[editor.playseq]->blocknumbers[i]]->name;
     gtk_clist_append(GTK_CLIST(gui_playseq_clist), columns);
   }
 
@@ -1011,11 +1044,12 @@ void gui_playseq_refresh() {
 
   snprintf(position, 9+8, "Position %d/%d", editor.playseqpos+1,
 	   editor.song->playseqs[editor.playseq]->length);
-  snprintf(block, 6+8, "Block %d/%d", editor.song->playseqs[editor.section]->blocknumbers[editor.playseqpos], editor.song->numblocks-1);
+  snprintf(block, 6+8, "Block %d/%d", editor.song->playseqs[editor.playseq]->blocknumbers[editor.playseqpos], editor.song->numblocks-1);
   gtk_frame_set_label(GTK_FRAME(gui_playseq_current), position);
   gtk_label_set_text(GTK_LABEL(gui_playseq_block), block);
 
-  snprintf(title, 21, "Playing Sequence %d", editor.section);
+  snprintf(title, 24, "Playing Sequence %d/%d", editor.playseq+1,
+	   editor.song->numplayseqs);
   gtk_window_set_title(GTK_WINDOW(gui_playseq_window), title);
 }
 
@@ -1028,21 +1062,21 @@ void gui_playseq_select_row(GtkWidget *list, gint row, gint column,
 
   snprintf(position, 9+8, "Position %d/%d", editor.playseqpos+1,
 	   editor.song->playseqs[editor.playseq]->length);
-  snprintf(block, 6+8, "Block %d/%d", editor.song->playseqs[editor.section]->blocknumbers[editor.playseqpos], editor.song->numblocks-1);
+  snprintf(block, 6+8, "Block %d/%d", editor.song->playseqs[editor.playseq]->blocknumbers[editor.playseqpos], editor.song->numblocks-1);
   gtk_frame_set_label(GTK_FRAME(gui_playseq_current), position);
   gtk_label_set_text(GTK_LABEL(gui_playseq_block), block);
 
   gui_info_refresh();
 }
 
-void gui_playseq_insnew() {
+void gui_playseq_insert() {
   if(editor.song!=NULL) {
     playseq_insert(editor.song->playseqs[editor.playseq], editor.playseqpos);
     gui_playseq_refresh();
   }
 }
 
-void gui_playseq_appnew() {
+void gui_playseq_append() {
   if(editor.song!=NULL) {
     playseq_insert(editor.song->playseqs[editor.playseq],
 		   editor.song->playseqs[editor.playseq]->length);
@@ -1057,20 +1091,47 @@ void gui_playseq_delete() {
   }
 }
 
+void gui_playseq_insertnew() {
+  if(editor.song!=NULL) {
+    song_insertplayseq(editor.song, editor.playseq);
+    gui_info_refresh();
+    gui_playseq_refresh();
+    gui_sectionlist_refresh();
+  }
+}
+
+void gui_playseq_appendnew() {
+  if(editor.song!=NULL) {
+    song_insertplayseq(editor.song, editor.song->numplayseqs);
+    gui_info_refresh();
+    gui_playseq_refresh();
+    gui_sectionlist_refresh();
+  }
+}
+
+void gui_playseq_deletecurrent() {
+  if(editor.song!=NULL) {
+    song_deleteplayseq(editor.song, editor.playseq);
+    gui_info_refresh();
+    gui_playseq_refresh();
+    gui_sectionlist_refresh();
+  }
+}
+
 void gui_playseq_previous() {
-  unsigned short playseq=editor.song->playseqs[editor.section]->blocknumbers[editor.playseqpos];
+  unsigned short playseq=editor.song->playseqs[editor.playseq]->blocknumbers[editor.playseqpos];
 
   if(playseq>0)
-    playseq_set(editor.song->playseqs[editor.section], editor.playseqpos,
+    playseq_set(editor.song->playseqs[editor.playseq], editor.playseqpos,
 		playseq-1);
   gui_playseq_refresh();
 }
 
 void gui_playseq_next() {
-  unsigned short playseq=editor.song->playseqs[editor.section]->blocknumbers[editor.playseqpos];
+  unsigned short playseq=editor.song->playseqs[editor.playseq]->blocknumbers[editor.playseqpos];
 
   if(playseq<editor.song->numblocks-1)
-    playseq_set(editor.song->playseqs[editor.section], editor.playseqpos,
+    playseq_set(editor.song->playseqs[editor.playseq], editor.playseqpos,
 		playseq+1);
   gui_playseq_refresh();
 }
@@ -1118,10 +1179,10 @@ void gui_blocklist_select_row(GtkWidget *list, gint row, gint column,
   editor.block=row;
 
   if(editor.song->blocks[row]->name)
-    gtk_entry_set_text(GTK_ENTRY(gui_blocklist_entry_name),
+    gtk_entry_set_text(GTK_ENTRY(gui_blocklist_name),
 		       editor.song->blocks[row]->name);
   else
-    gtk_entry_set_text(GTK_ENTRY(gui_blocklist_entry_name), "");
+    gtk_entry_set_text(GTK_ENTRY(gui_blocklist_name), "");
 
   snprintf(block, 6+8, "Block %d/%d", editor.block,
 	   editor.song->numblocks-1);
@@ -1155,7 +1216,7 @@ void gui_blocklist_activate_name(GtkWidget *widget, GtkWidget *entry) {
   }
 }
 
-void gui_blocklist_insnew() {
+void gui_blocklist_insert() {
   if(editor.song!=NULL) {
     song_insertblock(editor.song, editor.block);
     gui_blocklist_refresh();
@@ -1163,7 +1224,7 @@ void gui_blocklist_insnew() {
   }
 }
 
-void gui_blocklist_appnew() {
+void gui_blocklist_append() {
   if(editor.song!=NULL) {
     song_insertblock(editor.song, editor.song->numblocks);
     gui_blocklist_refresh();
