@@ -99,6 +99,13 @@ void song_free(struct song *song) {
 /* Inserts a new block in the block array in the given position */
 void song_insertblock(struct song *song, int pos) {
   int i;
+
+  /* Check block existence */
+  if(pos<0)
+    pos=0;
+  else if(pos>song->numblocks)
+    pos=song->numblocks;
+
   song->numblocks++;
   /* Reallocate the block array */
   song->blocks=(struct block **)realloc(song->blocks, song->numblocks*sizeof(struct block *));
@@ -125,6 +132,13 @@ void song_insertblock(struct song *song, int pos) {
 /* Deletes a block from the given position of the block array */
 void song_deleteblock(struct song *song, int pos) {
   int i;
+
+  /* Check block existence */
+  if(pos<0)
+    pos=0;
+  else if(pos>=song->numblocks)
+    pos=song->numblocks-1;
+
   /* Don't delete the last block */
   if(song->numblocks>1) {
     /* Free the block in question */
@@ -149,9 +163,72 @@ void song_deleteblock(struct song *song, int pos) {
   }
 }
 
+/* Inserts a new playseq in the playseq array in the given position */
+void song_insertplayseq(struct song *song, int pos) {
+  int i;
+
+  /* Check playseq existence */
+  if(pos<0)
+    pos=0;
+  else if(pos>song->numplayseqs)
+    pos=song->numplayseqs;
+
+  song->numplayseqs++;
+  /* Reallocate the playseqs array */
+  song->playseqs=(struct playseq **)realloc(song->playseqs, song->numplayseqs*sizeof(struct playseq *));
+
+  /* Move rest of the playseqs onwards */
+  for(i=song->numplayseqs-1; i>pos; i--)
+    song->playseqs[i]=song->playseqs[i-1];
+
+  /* Insert a new playing sequence */
+  song->playseqs[pos]=playseq_alloc();
+  
+  /* Update sections */
+  for(i=0; i<song->numsections; i++) {
+    if(song->sections[i]>=pos)
+	song->sections[i]++;
+  }
+}
+
+/* Deletes a playseq from the given position of the playseq array */
+void song_deleteplayseq(struct song *song, int pos) {
+  int i;
+  
+  /* Check block existence */
+  if(pos<0)
+    pos=0;
+  else if(pos>=song->numplayseqs)
+    pos=song->numplayseqs-1;
+
+  /* Don't delete the last playseq */
+  if(song->numplayseqs>1) {
+    /* Free the playseq to be deleted */
+    playseq_free(song->playseqs[pos]);
+    song->numplayseqs--;
+    
+    /* Move rest of the playseqs backwards */
+    for(i=pos; i<song->numplayseqs; i++)
+      song->playseqs[i]=song->playseqs[i+1];
+    
+    /* Reallocate the playseqs array */
+    song->playseqs=(struct playseq **)realloc(song->playseqs, song->numplayseqs*sizeof(struct playseq *));
+
+    refresh_playseq_and_block();
+  }
+}
+
+
 /* Inserts a new section in the section array in the given position */
 void song_insertsection(struct song *song, int pos) {
   int i;
+
+  /* Check block existence */
+  if(pos<0)
+    pos=0;
+  else if(pos>song->numsections)
+    pos=song->numsections;
+
   song->numsections++;
   /* Reallocate the sections array */
   song->sections=(unsigned short *)realloc(song->sections, song->numsections*sizeof(unsigned short));
@@ -165,6 +242,12 @@ void song_insertsection(struct song *song, int pos) {
 void song_deletesection(struct song *song, int pos) {
   int i;
   
+  /* Check block existence */
+  if(pos<0)
+    pos=0;
+  else if(pos>=song->numsections)
+    pos=song->numsections-1;
+
   /* Don't delete the last section */
   if(song->numsections>1) {
     song->numsections--;
